==> regina-normal_5.0.orig.tar.gz: regina-5.0/ios/NewPacketPageViewController.h <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  iOS User Interface                                                    *
 *                                                                        *
 *  Copyright (c) 1999-2016, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  As an exception, when this program is distributed through (i) the     *
 *  App Store by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or     *
 *  (iii) Google Play by Google Inc., then that store may impose any      *
 *  digital rights management, device limits and/or redistribution        *
 *  restrictions that are required by its terms of service.               *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
 *  MA 02110-1301, USA.                                                   *
 *                                                                        *
 **************************************************************************/

#import "NewPacketController.h"

namespace regina {
    class NPacket;
}

@protocol PacketCreator

// Must set the packet label also.
// Need not insert it into the tree.
// May return 0, but if so, should explain to
// the user why.
- (regina::NPacket*)create;

@end

@interface NewPacketPageViewController : UIPageViewController

// Storyboard controllers must all adhere to the PacketCreator protocol.
// The defaultKey may be nil.
- (void)fillWithPages:(NSArray*)storyboardIDs pageSelector:(UISegmentedControl*)s defaultKey:(NSString*)key;
- (regina::NPacket*)create;

@end

==> regina-normal_5.1.orig.tar.gz: regina-5.1/ios/NewPacketPageViewController.h <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  iOS User Interface                                                    *
 *                                                                        *
 *  Copyright (c) 1999-2016, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  As an exception, when this program is distributed through (i) the     *
 *  App Store by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or     *
 *  (iii) Google Play by Google Inc., then that store may impose any      *
 *  digital rights management, device limits and/or redistribution        *
 *  restrictions that are required by its terms of service.               *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
 *  MA 02110-1301, USA.                                                   *
 *                                                                        *
 **************************************************************************/

#import "NewPacketController.h"

namespace regina {
    class Packet;
}

@protocol PacketCreator

// Must set the packet label also.
// Need not insert it into the tree.
// May return 0, but if so, should explain to
// the user why.
- (regina::Packet*)create;

@end

@interface NewPacketPageViewController : UIPageViewController

// Storyboard controllers must all adhere to the PacketCreator protocol.
// The defaultKey may be nil.
- (void)fillWithPages:(NSArray*)storyboardIDs pageSelector:(UISegmentedControl*)s defaultKey:(NSString*)key;
- (regina::Packet*)create;

@end
